@@ -90,23 +90,7 @@ static int GetAvailableUpdateMenuId()
 
 std::map<int, std::pair<std::function<void(wxTextEntry*)>, wxChar>> keyboardCommands;
 
-#ifdef __WXMAC__
-wxTextEntry* GetSpecialTextEntry(wxWindow* w, wxChar cmd)
-{
-	if (cmd == 'A' || cmd == 'V') {
-		wxTextCtrl* text = dynamic_cast<wxTextCtrl*>(w);
-		if (text) {
-			return text;
-		}
-	}
-	return dynamic_cast<wxComboBox*>(w);
-}
-#else
-wxTextEntry* GetSpecialTextEntry(wxWindow*, wxChar)
-{
-	return 0;
-}
-#endif
+extern wxTextEntry* GetSpecialTextEntry(wxWindow*, wxChar);
 
 bool HandleKeyboardCommand(wxCommandEvent& event, wxWindow& parent)
 {
@@ -398,6 +382,8 @@ CMainFrame::CMainFrame(COptions& options)
 	cert_store_ = std::make_unique<CertStore>(options_.get_int(OPTION_DEFAULT_KIOSKMODE) == 2);
 	async_request_queue_ = std::make_unique<CAsyncRequestQueue>(this, options_, *cert_store_);
 
+	edit_handler_ = std::make_unique<CEditHandler>(options_);
+
 #ifdef __WXMSW__
 	long style = wxSP_NOBORDER | wxSP_LIVE_UPDATE;
 #elif !defined(__WXMAC__)
@@ -430,6 +416,10 @@ CMainFrame::CMainFrame(COptions& options)
 
 	m_pQueueView = m_pQueuePane->GetQueueView();
 
+	if (edit_handler_) {
+		edit_handler_->SetQueue(m_pQueueView);
+	}
+
 	m_pContextControl->Create(m_pBottomSplitter);
 
 	m_pStateEventHandler = new CMainFrameStateEventHandler(this);
@@ -517,10 +507,6 @@ CMainFrame::CMainFrame(COptions& options)
 	ConnectNavigationHandler(m_pStatusView);
 	ConnectNavigationHandler(m_pQueuePane);
 
-	CEditHandler::Create()->SetQueue(m_pQueueView);
-
-	CAutoAsciiFiles::SettingsChanged(options_);
-
 	FixTabOrder();
 
 	options_.watch(OPTION_ICONS_THEME, this);
@@ -555,12 +541,9 @@ CMainFrame::~CMainFrame()
 	delete m_pUpdater;
 #endif
 
-	CEditHandler* pEditHandler = CEditHandler::Get();
-	if (pEditHandler) {
-		// This might leave temporary files behind,
-		// edit handler should clean them on next startup
-		pEditHandler->Release();
-	}
+	// This might leave temporary files behind
+	// edit handler should clean them on next startup
+	edit_handler_.reset();
 
 #ifndef __WXMAC__
 	delete m_taskBarIcon;
@@ -833,7 +816,7 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 		dlg.Run(options_);
 	}
 	else if (id == XRCID("ID_MENU_FILE_EDITED")) {
-		CEditHandlerStatusDialog dlg(this);
+		CEditHandlerStatusDialog dlg(this, options_, edit_handler_.get());
 		dlg.ShowModal();
 	}
 	else if (id == XRCID("ID_MENU_TRANSFER_TYPE_AUTO")) {
@@ -1325,11 +1308,10 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 				}
 			}
 
-			CEditHandler* pEditHandler = CEditHandler::Get();
-			if (pEditHandler) {
-				if (pEditHandler->GetFileCount(CEditHandler::remote, CEditHandler::edit) || pEditHandler->GetFileCount(CEditHandler::none, CEditHandler::upload) ||
-					pEditHandler->GetFileCount(CEditHandler::none, CEditHandler::upload_and_remove) ||
-					pEditHandler->GetFileCount(CEditHandler::none, CEditHandler::upload_and_remove_failed))
+			if (edit_handler_) {
+				if (edit_handler_->GetFileCount(CEditHandler::remote, CEditHandler::edit) || edit_handler_->GetFileCount(CEditHandler::none, CEditHandler::upload) ||
+					edit_handler_->GetFileCount(CEditHandler::none, CEditHandler::upload_and_remove) ||
+					edit_handler_->GetFileCount(CEditHandler::none, CEditHandler::upload_and_remove_failed))
 				{
 					CConditionalDialog dlg(this, CConditionalDialog::confirmexit_edit, CConditionalDialog::yesno, options_);
 					dlg.SetTitle(_("Close FileZilla"));
@@ -1387,10 +1369,9 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 		return;
 	}
 
-	CEditHandler* pEditHandler = CEditHandler::Get();
-	if (pEditHandler) {
-		pEditHandler->RemoveAll(true);
-		pEditHandler->Release();
+	if (edit_handler_) {
+		edit_handler_->RemoveAll(true);
+		edit_handler_.reset();
 	}
 
 	bool res = true;
@@ -2433,9 +2414,8 @@ void CMainFrame::OnActivate(wxActivateEvent& event)
 		return;
 	}
 
-	CEditHandler* pEditHandler = CEditHandler::Get();
-	if (pEditHandler) {
-		pEditHandler->CheckForModifications();
+	if (edit_handler_) {
+		edit_handler_->CheckForModifications();
 	}
 
 	if (async_request_queue_) {
@@ -2827,7 +2807,7 @@ void CMainFrame::OnSearch(wxCommandEvent&)
 		return;
 	}
 
-	CSearchDialog dlg(this, *pState, m_pQueueView, options_);
+	CSearchDialog dlg(this, *pState, m_pQueueView, options_, edit_handler_.get());
 	if (!dlg.Load()) {
 		return;
 	}
